@@ -48,7 +48,7 @@ pub trait SiemComponent : Send {
 
 pub trait SiemDatasetManager : Send {
     fn name(&self) -> Cow<'static, str>{
-        return Cow::Borrowed("SiemComponent")
+        return Cow::Borrowed("SiemDatasetManager")
     }
     /// Get the channel to this component
     fn local_channel(&self) -> Sender<SiemMessage>;
@@ -60,11 +60,11 @@ pub trait SiemDatasetManager : Send {
     fn run(&mut self);
 
     /// Get the list of datasets to initialize components
-    fn get_datasets(&self) -> Vec<SiemDataset>;
+    fn get_datasets(&self) -> Arc<Mutex<Vec<SiemDataset>>>;
 
     /// Sets the map of components that need dataset updates
     fn set_dataset_channels(&mut self, channels : Arc<Mutex<BTreeMap<String,Vec<Sender<SiemMessage>>>>>);
 
     /// Allows the Kernel to duplicate this component
-    fn duplicate(&self) -> Box<dyn SiemComponent>;
+    fn duplicate(&self) -> Box<dyn SiemDatasetManager>;
 }
\ No newline at end of file
